@@ -1,4 +1,4 @@
-## Domain Registry Interface, ``WorldSite.WS'' Registry Driver for .WS
+## Domain Registry Interface, "WorldSite.WS" Registry Driver for .WS
 ##
 ## Copyright (c) 2005,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
@@ -10,20 +10,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::DRD::WS;
 
 use strict;
+use warnings;
+
 use base qw/Net::DRI::DRD/;
 
 use DateTime::Duration;
 
-our $VERSION=do { my @r=(q$Revision: 1.10 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -70,25 +67,15 @@ sub periods      { return map { DateTime::Duration->new(years => $_) } (1..10);
 sub name         { return 'WS'; }
 sub tlds         { return ('ws'); }
 sub object_types { return ('domain','ns'); }
-
-sub transport_protocol_compatible 
-{
- my ($self,$to,$po)=@_;
- my $pn=$po->name();
- my $pv=$po->version();
- my $tn=$to->name();
-
- return 1 if (($pn eq 'RRP') && ($tn eq 'socket_inet'));
- return 1 if (($pn eq 'Whois') && ($tn eq 'socket_inet'));
- return;
-}
+sub profile_types { return qw/rrp whois/; }
 
 sub transport_protocol_default
 {
- my ($drd,$ndr,$type,$ta,$pa)=@_;
- $type='rrp' if (!defined($type) || ref($type));
- return ('Net::DRI::Transport::Socket',$ta,'Net::DRI::Protocol::RRP',$pa) if ($type eq 'rrp');
- return ('Net::DRI::Transport::Socket',[{%Net::DRI::DRD::PROTOCOL_DEFAULT_WHOIS,remote_host=>'whois.nic.ws'}],'Net::DRI::Protocol::Whois',[]) if (lc($type) eq 'whois');
+ my ($self,$type)=@_;
+
+ return ('Net::DRI::Transport::Socket',{},'Net::DRI::Protocol::RRP',{})                              if $type eq 'rrp';
+ return ('Net::DRI::Transport::Socket',{remote_host=>'whois.nic.ws'},'Net::DRI::Protocol::Whois',{}) if $type eq 'whois';
+ return;
 }
 
 ####################################################################################################
