@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for .SI
 ##
-## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -15,6 +15,8 @@
 package Net::DRI::Data::Contact::ARNES;
 
 use strict;
+use warnings;
+
 use base qw/Net::DRI::Data::Contact/;
 
 __PACKAGE__->register_attributes(qw(maticna emso));
@@ -60,7 +62,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -98,6 +100,7 @@ sub init
  {
   $self->srid('auto') unless defined($self->srid()); ## we can not choose the ID
  }
+ return;
 }
 
 
