@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .AU Domain EPP extension commands
 ##
-## Copyright (c) 2007,2008 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
+## Copyright (c) 2007,2008,2013 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -15,6 +15,7 @@
 package Net::DRI::Protocol::EPP::Extensions::AU::Domain;
 
 use strict;
+use warnings;
 
 use Net::DRI::Exception;
 
@@ -46,7 +47,7 @@ Rony Meyer, E<lt>perl@spot-light.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
+Copyright (c) 2007,2008,2013 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -114,6 +115,7 @@ sub create
  push @nn, ['auext:create',@n];
 
  $mes->command_extension($eid,\@nn);
+ return;
 }
 
 
@@ -170,6 +172,7 @@ sub info_parse
  } continue { $c=$c->getNextSibling(); }
 
  $rinfo->{domain}->{$oname}->{eligibility}=\%ens;
+ return;
 }
 ####################################################################################################
 1;
